@@ -228,7 +228,6 @@ def _prepare_filesystem(config):
         __try_to_set_owner(
             int(fileconfig['OWNER_UID']),
             config.dirs['user_conf_dir'],
-            autofix=True,
         )
     for subdir in ['config', 'sqlscripts', 'debug', 'proxy']:
         path = config.dirs['run'] / subdir
@@ -236,7 +235,6 @@ def _prepare_filesystem(config):
         __try_to_set_owner(
             int(fileconfig['OWNER_UID']),
             path,
-            autofix=config.devmode
         )
 
 def get_db_name(db, project_name):
@@ -266,12 +264,6 @@ def setup_settings_file(config, db, demo, **forced_values):
         if settings.get(k, '') != v:
             settings[k] = v
             settings.write()
-    config_compose_minimum = MyConfigParser(config.files['settings_auto'])
-    config_compose_minimum.clear()
-    for k in vals.keys():
-        config_compose_minimum[k] = vals[k]
-
-    config_compose_minimum.write()
 
 def _execute_after_compose(config, yml):
     """
