@@ -30,7 +30,7 @@ def odoo_module(config):
 
 @odoo_module.command(name='abort-upgrade')
 @pass_config
-def abort_upgrade(config):
+def abort_upgrade():
     click.echo("Aborting upgrade...")
     SQL = """
         UPDATE ir_module_module SET state = 'installed' WHERE state = 'to upgrade';
